-- Xtier Schema Extentions
-- Novell Inc.
-- 122 East 1700 South
-- Provo, UT 84606-6194

-- VeRsIoN=xtier 1.0
-- CoPyRiGhT=(c) Copyright 2001, Novell, Inc.  All rights reserved

-- Object ID Syntax
------------------------------------------

XTierExtensions DEFINITIONS ::=
BEGIN

--
-- create xTier iFolder passphrase attribute
-- Single-valued string
-- Syntax: SYN_CE_STRING (IA-5 String)
--
-- ldif equivalent:
-- dn: cn=schema
-- changetype: modify
-- add: attributeTypes
-- attributeTypes: ( 2.16.840.1.113719.2.252.4.1 NAME 'xTier-iFolderPassphrase' SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE)

"xTier-iFolderPassphrase" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CE_STRING,
	ASN1ObjID		{2 16 840 1 113719 2 252 4 1}
}

--
-- create xTier-URL attribute
-- Single-valued string
-- Syntax: SYN_CE_STRING (IA-5 String)
-- Used to specify the URL used for access to a storage location

"xTier-URL" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CE_STRING,
	ASN1ObjID		{2 16 840 1 113719 2 252 4 2}
}

--
-- create xTier-LocationList attribute
-- Multi-valued DN
-- Syntax: SYN_DIST_NAME 
-- Used for a list of storage locations to be made available to a User, Group, O, OU, Locality, Country, or Profile.

"xTier-LocationList" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 2 252 4 3}
}

--
-- create xTier Auxiliary class
-- may contain xTier-iFolderPassphrase attribute
--
-- ldif equivalent:
-- dn: cn=schema
-- changetype: modify
-- add: objectclasses
-- objectclasses: (2.16.840.1.113719.2.252.6.1 NAME 'xTier' MAY (xTier-iFolderPassphrase) AUXILIARY)

"xTier" OBJECT-CLASS ::=
{
	Operation		ADD,
  	Flags      		{DS_AUXILIARY_CLASS},
	MayContain		{"xTier-iFolderPassphrase"},
	ASN1ObjID		{2 16 840 1 113719 2 252 6 1}
}

-- create xTier-Locations Auxiliary class
-- may contain xTier-LocationList
-- Used to extend User, Group, O, OU, C, Locality, Country, or Profile objects.
-- xTier-LocationList is a multi valued attribute that points to StorageLocation objects,
-- which are used to define Storage that should be made available available to a user.
-- xTier will search for xTier-LocationList attributes in the same places that a client would
-- look for login scripts.

"xTier-Locations" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_AUXILIARY_CLASS},
	MayContain		{"xTier-LocationList"},
	ASN1ObjID		{2 16 840 1 113719 2 252 6 2}
}

-- create xTier-StorageLocation class
-- must contain CN xTier-URL and displayName
-- may contain Description
-- This object is used to define storage locations to be made available through xTier.
-- xTier is configured to create these objects in a known container, however these objects
-- can also be created and used in other containers. xTier looks at xTier-LocationList attributes 
-- on objects to find which objects should be used for a user, see xTier-Locations.
-- When xTier-StorageLocation objects are in xTier's known container they will be used to
-- allow users to discover possible Storage Locations. Directory ACLs can be used to determine
-- which users will be able to "discover" any one Storage Location.
-- 
-- Attributes
-- CN:          Used for naming the object. xTier will generate unique names when creating
--              Storage location objects. These names will not be the names to be displayed
--              to a user.
-- xTier-URL:   The is the actual location of the storage to be used. Some possible locations
--              could be: ncp://ncpserver.novell.com/vol/path, http://WebDAVserver.novell.com/, 
--              ftp://ftpserver.novell.com/public, cifs://windows.server.novell.com/share
-- displayName: This is the actual name shown to the user, such as "Team Files"
-- Description: More detailed information about the storage location, 
--              such as "Design documents for the NetStorage team"

"xTier-StorageLocation" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS},
	SubClassOf		{"TOP"},
	ContainedBy		{"Organization", "Organizational Unit"},
	NamedBy			{"CN"},
	MustContain		{"CN","xTier-URL", "displayName"},
	MayContain		{"Description"},
	ASN1ObjID		{2 16 840 1 113719 2 252 6 3}
}
END

